==> adbrixrm_flutter-2.1.0-dev.1.tar.gz: ios/Classes/AdbrixEventChannel.swift <==
//
//  AdbrixEventChannel.swift
//  adbrixrm_flutter
//
//  Created by Jimmy.강세훈 on 2023/04/25.
//

import Foundation
import Flutter
import AdBrixRmKit

class AdBrixEventChannel: NSObject, FlutterStreamHandler, AdBrixRMDeeplinkDelegate, AdBrixRMDeferredDeeplinkDelegate, AdBrixRmPushLocalDelegate, AdBrixRmPushRemoteDelegate, AdBrixRMInAppMessageClickDelegate, DfnInAppMessageAutoFetchDelegate, AdBrixRMLogDelegate {
    
    let ARGUMENT_Deeplink = "com.adbrix.stream.deeplink"
    let ARGUMENT_DeferredDeeplink = "com.adbrix.stream.deferredDeeplink"
    let ARGUMENT_PushLocalCallback = "com.adbrix.stream.pushLocalCallBack"
    let ARGUMENT_PushRemoteCallback = "com.adbrix.stream.pushRemoteCallback"
    let ARGUMENT_OnReceiveInAppMessageClick = "com.adbrix.stream.onReceiveInAppMessageClick"
    let ARGUMENT_DidFetchInAppMessage = "com.adbrix.stream.didFetchInAppMessage"
    let ARGUMENT_DidPrintLog = "com.adbrix.stream.didPrintLog"
    
    let ERROR_CODE_SDK_ERROR = "-1";
    
    var sinkDeeplink: FlutterEventSink?
    var sinkDeferredDeeplink: FlutterEventSink?
    var sinkPushLocalCallback: FlutterEventSink?
    var sinkPushRemoteCallback: FlutterEventSink?
    var sinkOnReceiveInAppMessageClick: FlutterEventSink?
    var sinkDidFetchInAppMessage: FlutterEventSink?
    var sinkDidPrintLog: FlutterEventSink?
    
    var initialDeeplink: String?
    
    var initialDeferredDeeplink: String?
    
    static let shared = AdBrixEventChannel()
    
    private override init() {}
    
    public func onListen(withArguments arguments: Any?, eventSink events: @escaping FlutterEventSink) -> FlutterError? {
        if let argument = arguments as? String {
            switch argument {
            case ARGUMENT_Deeplink:
                sinkDeeplink = events
                if let _initialDeeplink = initialDeeplink {
                    if let sinkDeeplink = sinkDeeplink {
                        sinkDeeplink(_initialDeeplink)
                        initialDeeplink = nil
                    }
                }
                
            case ARGUMENT_DeferredDeeplink:
                sinkDeferredDeeplink = events
                if let _initialDefferedDeeplink = initialDeferredDeeplink {
                    if let sinkDeferredDeeplink = sinkDeferredDeeplink {
                        sinkDeferredDeeplink(_initialDefferedDeeplink)
                        initialDeferredDeeplink = nil
                    }
                }
                
            case ARGUMENT_PushLocalCallback:
                sinkPushLocalCallback = events
                
            case ARGUMENT_PushRemoteCallback:
                sinkPushRemoteCallback = events
                
            case ARGUMENT_OnReceiveInAppMessageClick:
                sinkOnReceiveInAppMessageClick = events
                
            case ARGUMENT_DidFetchInAppMessage:
                sinkDidFetchInAppMessage = events
                
            case ARGUMENT_DidPrintLog:
                sinkDidPrintLog = events
                
            default:
                return FlutterError(code: ERROR_CODE_SDK_ERROR, message: "Wrong Argument in event stream onListen", details: nil)
            }
        }
        return nil
    }
    
    public func onCancel(withArguments arguments: Any?) -> FlutterError? {
        if let argument = arguments as? String {
            switch argument {
            case ARGUMENT_Deeplink:
                sinkDeeplink = nil
            case ARGUMENT_DeferredDeeplink:
                sinkDeferredDeeplink = nil
            case ARGUMENT_PushLocalCallback:
                sinkPushLocalCallback = nil
            case ARGUMENT_PushRemoteCallback:
                sinkPushRemoteCallback = nil
            case ARGUMENT_OnReceiveInAppMessageClick:
                sinkOnReceiveInAppMessageClick = nil
            case ARGUMENT_DidFetchInAppMessage:
                sinkDidFetchInAppMessage = nil
            case ARGUMENT_DidPrintLog:
                sinkDidPrintLog = nil
            default:
                return FlutterError(code: ERROR_CODE_SDK_ERROR, message: "Wrong Argument in event stream onCancel", details: nil)
            }
        }
        return nil
    }
    
    public func didReceiveDeeplink(deeplink: String) {
        if let sinkDeeplink = sinkDeeplink {
            sinkDeeplink(deeplink)
        } else {
            initialDeeplink = deeplink
        }
    }
    
    public func didReceiveDeferredDeeplink(deeplink: String) {
        if let sinkDeferredDeeplink = sinkDeferredDeeplink {
            sinkDeferredDeeplink(deeplink)
        } else {
            initialDeferredDeeplink = deeplink
        }
    }
    
    public func pushLocalCallback(data: [String: Any]?, state: UIApplication.State) {
        if let sinkPushLocalCallback = sinkPushLocalCallback {
            if let data = data?.toJsonFormat() {
                sinkPushLocalCallback(data)
            }
        }
    }
    
    public func pushRemoteCallback(data: [String: Any]?, state: UIApplication.State) {
        if let sinkPushRemoteCallback = sinkPushRemoteCallback {
            if let data = data?.toJsonFormat() {
                sinkPushRemoteCallback(data)
            }
        }
    }
    
    public func onReceiveInAppMessageClick(actionId: String, actionType: String, actionArg: String, isClosed: Bool) {
        if let sinkOnReceiveInAppMessageClick = sinkOnReceiveInAppMessageClick {
            if let result = (["actionId": actionId,
                              "actionType": actionType,
                              "actionArg": actionArg,
                              "isClosed": isClosed] as [String : Any]).toJsonFormat() {
                sinkOnReceiveInAppMessageClick(result)
            }
        }
    }
    
    public func didFetchInAppMessage(result: AdBrixRmKit.DfnInAppMessageFetchResult) {
        if let sinkDidFetchInAppMessage = sinkDidFetchInAppMessage {
            sinkDidFetchInAppMessage(result.isSucceeded)
        }
    }
    
    public func didPrintLog(level: AdBrixRmKit.AdBrixRM.AdBrixLogLevel, log: String) {
        if let sinkDidPrintLog = sinkDidPrintLog {
            sinkDidPrintLog(log)
        }
    }

}

==> adbrixrm_flutter-3.0.0-dev.3.tar.gz: ios/Classes/AdbrixEventChannel.swift <==
//
//  AdbrixEventChannel.swift
//  adbrixrm_flutter
//
//  Created by Jimmy.강세훈 on 2023/04/25.
//

import Foundation
import Flutter
import AdBrixRmKit

class AdBrixEventChannel: NSObject, FlutterStreamHandler, AdBrixRMDeeplinkDelegate, AdBrixRMDeferredDeeplinkDelegate, AdBrixRmPushRemoteDelegate, AdBrixRMInAppMessageClickDelegate {
    
    let ARGUMENT_Deeplink = "com.adbrix.stream.deeplink"
    let ARGUMENT_DeferredDeeplink = "com.adbrix.stream.deferredDeeplink"
    let ARGUMENT_PushRemoteCallback = "com.adbrix.stream.pushRemoteCallback"
    let ARGUMENT_OnReceiveInAppMessageClick = "com.adbrix.stream.onReceiveInAppMessageClick"
    
    let ERROR_CODE_SDK_ERROR = "-1";
    
    var sinkDeeplink: FlutterEventSink?
    var sinkDeferredDeeplink: FlutterEventSink?
    var sinkPushRemoteCallback: FlutterEventSink?
    var sinkOnReceiveInAppMessageClick: FlutterEventSink?
    
    var initialDeeplink: String?
    
    var initialDeferredDeeplink: String?
    
    var initialPushData: String?
    
    static let shared = AdBrixEventChannel()
    
    private override init() {}
    
    public func onListen(withArguments arguments: Any?, eventSink events: @escaping FlutterEventSink) -> FlutterError? {
        if let argument = arguments as? String {
            switch argument {
            case ARGUMENT_Deeplink:
                sinkDeeplink = events
                if let _initialDeeplink = initialDeeplink {
                    if let sinkDeeplink = sinkDeeplink {
                        sinkDeeplink(_initialDeeplink)
                        initialDeeplink = nil
                    }
                }
                
            case ARGUMENT_DeferredDeeplink:
                sinkDeferredDeeplink = events
                if let _initialDefferedDeeplink = initialDeferredDeeplink {
                    if let sinkDeferredDeeplink = sinkDeferredDeeplink {
                        sinkDeferredDeeplink(_initialDefferedDeeplink)
                        initialDeferredDeeplink = nil
                    }
                }
                
            case ARGUMENT_PushRemoteCallback:
                sinkPushRemoteCallback = events
                if let _initialPushData = initialPushData {
                    if let sinkPushRemoteCallback = sinkPushRemoteCallback {
                        sinkPushRemoteCallback(_initialPushData)
                        initialPushData = nil
                    }
                }
                
            case ARGUMENT_OnReceiveInAppMessageClick:
                sinkOnReceiveInAppMessageClick = events
                                
            default:
                return FlutterError(code: ERROR_CODE_SDK_ERROR, message: "Wrong Argument in event stream onListen", details: nil)
            }
        }
        return nil
    }
    
    public func onCancel(withArguments arguments: Any?) -> FlutterError? {
        if let argument = arguments as? String {
            switch argument {
            case ARGUMENT_Deeplink:
                sinkDeeplink = nil
            case ARGUMENT_DeferredDeeplink:
                sinkDeferredDeeplink = nil
            case ARGUMENT_PushRemoteCallback:
                sinkPushRemoteCallback = nil
            case ARGUMENT_OnReceiveInAppMessageClick:
                sinkOnReceiveInAppMessageClick = nil
            default:
                return FlutterError(code: ERROR_CODE_SDK_ERROR, message: "Wrong Argument in event stream onCancel", details: nil)
            }
        }
        return nil
    }
    
    public func didReceiveDeeplink(deeplink: String) {
        if let sinkDeeplink = sinkDeeplink {
            sinkDeeplink(deeplink)
        } else {
            initialDeeplink = deeplink
        }
    }
    
    public func didReceiveDeferredDeeplink(deeplink: String) {
        if let sinkDeferredDeeplink = sinkDeferredDeeplink {
            sinkDeferredDeeplink(deeplink)
        } else {
            initialDeferredDeeplink = deeplink
        }
    }
    
    public func pushRemoteCallback(data: [String: Any]?, state: UIApplication.State) {
        guard let data = data?.toJsonFormat() else {return}
        if let sinkPushRemoteCallback = sinkPushRemoteCallback {
            sinkPushRemoteCallback(data)
        } else {
            initialPushData = data
        }
    }
    
    public func onReceiveInAppMessageClick(actionId: String, actionType: String, actionArg: String, isClosed: Bool) {
        if let sinkOnReceiveInAppMessageClick = sinkOnReceiveInAppMessageClick {
            if let result = (["actionId": actionId,
                              "actionType": actionType,
                              "actionArg": actionArg,
                              "isClosed": isClosed] as [String : Any]).toJsonFormat() {
                sinkOnReceiveInAppMessageClick(result)
            }
        }
    }
    
}
